=====================================================
Microsoft.Recognizers.Text.Choice for Python
=====================================================

This module (``recognizers-text-choice``) is a sub-module of
``recognizers-text-suite``.

Please check the `main README`_ for more details.

.. _main README: https://github.com/Microsoft/Recognizers-Text/tree/master/Python